package org.dromara.filemanager.service.impl;

import cn.hutool.core.thread.ThreadUtil;
import org.dromara.common.core.utils.MapstructUtils;
import org.dromara.common.core.utils.StringUtils;
import org.dromara.common.mybatis.core.page.TableDataInfo;
import org.dromara.common.mybatis.core.page.PageQuery;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;
import org.dromara.filemanager.domain.bo.TblArchivesFileBo;
import org.dromara.filemanager.domain.vo.TblArchivesFileVo;
import org.dromara.filemanager.domain.TblArchivesFile;
import org.dromara.filemanager.mapper.TblArchivesFileMapper;
import org.dromara.filemanager.service.ITblArchivesFileService;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Collection;

/**
 * 项目文件Service业务层处理
 *
 * @author Lion Li
 * @date 2024-06-06
 */
@RequiredArgsConstructor
@Service
public class TblArchivesFileServiceImpl implements ITblArchivesFileService {

    private final TblArchivesFileMapper baseMapper;

    /**
     * 查询项目文件
     */
    @Override
    public TblArchivesFileVo queryById(Long id){
        return baseMapper.selectVoById(id);
    }

    /**
     * 查询项目文件列表
     */
    @Override
    public TableDataInfo<TblArchivesFileVo> queryPageList(TblArchivesFileBo bo, PageQuery pageQuery) {
        LambdaQueryWrapper<TblArchivesFile> lqw = buildQueryWrapper(bo);
        Page<TblArchivesFileVo> result = baseMapper.selectVoPage(pageQuery.build(), lqw);
        return TableDataInfo.build(result);
    }

    /**
     * 查询项目文件列表
     */
    @Override
    public List<TblArchivesFileVo> queryList(TblArchivesFileBo bo) {
        try {
            baseMapper.delUnUsedFils();
        }catch (Exception e){}
        LambdaQueryWrapper<TblArchivesFile> lqw = buildQueryWrapper(bo);
        return baseMapper.selectVoList(lqw);
    }

    private LambdaQueryWrapper<TblArchivesFile> buildQueryWrapper(TblArchivesFileBo bo) {
        Map<String, Object> params = bo.getParams();
        LambdaQueryWrapper<TblArchivesFile> lqw = Wrappers.lambdaQuery();
        lqw.eq(bo.getOssFileId() != null, TblArchivesFile::getOssFileId, bo.getOssFileId());
        lqw.eq(bo.getArchiveId() != null, TblArchivesFile::getArchiveId, bo.getArchiveId());
        return lqw;
    }

    /**
     * 新增项目文件
     */
    @Override
    public Boolean insertByBo(TblArchivesFileBo bo) {
        TblArchivesFile add = MapstructUtils.convert(bo, TblArchivesFile.class);
        validEntityBeforeSave(add);
        boolean flag = baseMapper.insert(add) > 0;
        if (flag) {
            bo.setId(add.getId());
        }
        return flag;
    }

    @Override
    public Boolean insertBatch(List<TblArchivesFileBo> bos) {
        List<TblArchivesFile> files = new ArrayList<>();
        for (TblArchivesFileBo bo : bos) {
            TblArchivesFile add = MapstructUtils.convert(bo, TblArchivesFile.class);
            validEntityBeforeSave(add);
            files.add(add);
        }
        boolean flag = baseMapper.insertBatch(files);
        return flag;
    }

    /**
     * 修改项目文件
     */
    @Override
    public Boolean updateByBo(TblArchivesFileBo bo) {
        TblArchivesFile update = MapstructUtils.convert(bo, TblArchivesFile.class);
        validEntityBeforeSave(update);
        return baseMapper.updateById(update) > 0;
    }

    /**
     * 保存前的数据校验
     */
    private void validEntityBeforeSave(TblArchivesFile entity){
        //TODO 做一些数据校验,如唯一约束
    }

    /**
     * 批量删除项目文件
     */
    @Override
    public Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid) {
        if(isValid){
            //TODO 做一些业务上的校验,判断是否需要校验
        }
        return baseMapper.deleteBatchIds(ids) > 0;
    }

    @Override
    public Boolean deleteUnusedFiles() {

        return null;
    }
}
