package org.dromara.filemanager.service.impl;

import cn.hutool.core.thread.ThreadUtil;
import cn.hutool.core.util.StrUtil;
import org.dromara.common.core.utils.MapstructUtils;
import org.dromara.common.core.utils.StringUtils;
import org.dromara.common.mybatis.core.page.TableDataInfo;
import org.dromara.common.mybatis.core.page.PageQuery;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import lombok.RequiredArgsConstructor;
import org.dromara.filemanager.mapper.TblArchivesFileMapper;
import org.springframework.stereotype.Service;
import org.dromara.filemanager.domain.bo.TblArchivesBo;
import org.dromara.filemanager.domain.vo.TblArchivesVo;
import org.dromara.filemanager.domain.TblArchives;
import org.dromara.filemanager.mapper.TblArchivesMapper;
import org.dromara.filemanager.service.ITblArchivesService;

import java.util.List;
import java.util.Map;
import java.util.Collection;
import java.util.concurrent.ThreadFactory;
import java.util.concurrent.ThreadPoolExecutor;

/**
 * 电子档案Service业务层处理
 *
 * @author Lion Li
 * @date 2024-05-20
 */
@RequiredArgsConstructor
@Service
public class TblArchivesServiceImpl implements ITblArchivesService {

    private final TblArchivesMapper baseMapper;

    private final TblArchivesFileMapper fileMapper;

    /**
     * 查询电子档案
     */
    @Override
    public TblArchivesVo queryById(Long id){
        return baseMapper.selectVoById(id);
    }

    /**
     * 查询电子档案列表
     */
    @Override
    public TableDataInfo<TblArchivesVo> queryPageList(TblArchivesBo bo, PageQuery pageQuery) {

        //删除多余的文件关系
        try {
            ThreadUtil.execAsync(
                () -> {
                    fileMapper.delUnUsedFils();
                }
            );

        }catch (Exception e){}

        LambdaQueryWrapper<TblArchives> lqw = buildQueryWrapper(bo);
        Page<TblArchivesVo> result = baseMapper.selectVoPage(pageQuery.build(), lqw);
        return TableDataInfo.build(result);
    }

    /**
     * 查询电子档案列表
     */
    @Override
    public List<TblArchivesVo> queryList(TblArchivesBo bo) {
        LambdaQueryWrapper<TblArchives> lqw = buildQueryWrapper(bo);
        return baseMapper.selectVoList(lqw);
    }

    private LambdaQueryWrapper<TblArchives> buildQueryWrapper(TblArchivesBo bo) {
        Map<String, Object> params = bo.getParams();
        LambdaQueryWrapper<TblArchives> lqw = Wrappers.lambdaQuery();
        lqw.eq(StringUtils.isNotBlank(bo.getArea()), TblArchives::getArea, bo.getArea());
        lqw.eq(StringUtils.isNotBlank(bo.getStatus()), TblArchives::getStatus, bo.getStatus());
        lqw.like(StringUtils.isNotBlank(bo.getQiuquan()), TblArchives::getQiuquan, bo.getQiuquan());
//        lqw.eq(StringUtils.isNotBlank(bo.getQiuquan()), TblArchives::getQiuquan, bo.getQiuquan());
        lqw.like(StringUtils.isNotBlank(bo.getBuildUnit()), TblArchives::getBuildUnit, bo.getBuildUnit());
        lqw.like(StringUtils.isNotBlank(bo.getAddr()), TblArchives::getAddr, bo.getAddr());
        lqw.like(StringUtils.isNotBlank(bo.getCommunity()), TblArchives::getCommunity, bo.getCommunity());
        lqw.eq(bo.getAchievementDate() != null, TblArchives::getAchievementDate, bo.getAchievementDate());
        lqw.eq(bo.getSavePeriod() != null, TblArchives::getSavePeriod, bo.getSavePeriod());
        lqw.eq(StringUtils.isNotBlank(bo.getEcode()), TblArchives::getEcode, bo.getEcode());
        lqw.like(StringUtils.isNotBlank(bo.getSaveAddr()), TblArchives::getSaveAddr, bo.getSaveAddr());
        lqw.eq(StringUtils.isNotBlank(bo.getExt1()), TblArchives::getExt1, bo.getExt1());
        lqw.like(StringUtils.isNotBlank(bo.getRemark()), TblArchives::getRemark, bo.getRemark());
        lqw.eq(StringUtils.isNotBlank(bo.getExt2()), TblArchives::getExt2, bo.getExt2());
        return lqw;
    }

    /**
     * 新增电子档案
     */
    @Override
    public Boolean insertByBo(TblArchivesBo bo) {
        if(StrUtil.isEmptyIfStr(bo.getExt1())){
            bo.setExt1("{}");
        }
        if(StrUtil.isEmptyIfStr(bo.getExt2())){
            bo.setExt2("{}");
        }
        TblArchives add = MapstructUtils.convert(bo, TblArchives.class);
        validEntityBeforeSave(add);
        boolean flag = baseMapper.insert(add) > 0;
        if (flag) {
            bo.setId(add.getId());
        }
        return flag;
    }

    /**
     * 修改电子档案
     */
    @Override
    public Boolean updateByBo(TblArchivesBo bo) {
        TblArchives update = MapstructUtils.convert(bo, TblArchives.class);
        validEntityBeforeSave(update);
        return baseMapper.updateById(update) > 0;
    }

    /**
     * 保存前的数据校验
     */
    private void validEntityBeforeSave(TblArchives entity){
        //TODO 做一些数据校验,如唯一约束
    }

    /**
     * 批量删除电子档案
     */
    @Override
    public Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid) {
        if(isValid){
            //TODO 做一些业务上的校验,判断是否需要校验
        }
        return baseMapper.deleteBatchIds(ids) > 0;
    }
}
